{% extends "master_ass.html" %}
{% block body %}
        <h2 class="content-subhead">About Associations</h2>

        <p>Copyright © 2014 <a href="http://pronoy.in">Pronoy Chopra</a></p>
        <strong>University of Oklahoma</strong>
        <p><strong>Special thanks to</strong>: Wayne Smith, Funkybob (#django) and my friends at CCE IT</p>
{% endblock %}