{% extends "master_ass.html" %}
{% block body %}
<h2 class="content-subhead">{{ app_name }}</h2>
{% for association in associations.items %}
<div class="panel">
        <h4 class="content-subhead"><code><mark>{{ association.1.regex }}</mark></code></h4>
        <pre>
        <strong>View Name</strong>: <span class="listvalue">{{ association.1.view_name }}</span>
        <strong>URL Name</strong>: <span class="listvalue">{{ association.0 }}</span>
        <strong>Template</strong>: <span class="listvalue">{{ association.1.templates|default_if_none:"Improperly configured" }}</span>
        </pre>
        <!-- <a href="" class="pure-button pure-button-xsmall pure-button-primary">More Details</a> -->
</div>

{% endfor %}
{% endblock %}