import os
import sys
from django.test import TestCase
from utils import get_django_settings
# Create your tests here.

class SettingsImportTest(TestCase):
    def test_import_settings_module_from_django_base_dir(self):

        return None
